@@ -1,5 +1,7 @@
 package Search::Typesense::Types;
 
+# ABSTRACT: Types and type tools for Search::Typesense
+
 use strict;
 use warnings;
 use Type::Library -base;
@@ -8,7 +10,7 @@ use Type::Utils -all;
 # this gets us compile and compile_named
 use Type::Params;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our @EXPORT_OK;
 
@@ -28,9 +30,17 @@ BEGIN {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Search::Typesense::Types - Keep our type tools orgnanized
+Search::Typesense::Types - Types and type tools for Search::Typesense
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -84,3 +94,16 @@ See L<Type::Params>
 See L<Types::Standard>
 
 =back
+
+=head1 AUTHOR
+
+Curtis "Ovid" Poe <ovid@allaroundtheworld.fr>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by Curtis "Ovid" Poe.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
