@@ -1,5 +1,7 @@
 package Search::Typesense::Version;
 
+# ABSTRACT: Version object for the Typesense server version
+
 use Moo;
 use Carp qw(croak);
 use Search::Typesense::Types qw(
@@ -7,7 +9,7 @@ use Search::Typesense::Types qw(
   PositiveOrZeroInt
 );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 has version_string => (
     is       => 'ro',
@@ -45,9 +47,17 @@ sub comparator {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Search::Typesense::Version - Version object for the Typesense server
+Search::Typesense::Version - Version object for the Typesense server version
+
+=head1 VERSION
+
+version 0.08
 
 =head1 DESCRIPTION
 
@@ -87,3 +97,16 @@ Returns the patch version number.
 =head2 C<comparator>
 
 Returns a numeric string suitable for numeric comparisons between versions.
+
+=head1 AUTHOR
+
+Curtis "Ovid" Poe <ovid@allaroundtheworld.fr>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by Curtis "Ovid" Poe.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
